module.exports = defineTest({
	description: 'Does not fail when iteratively chaining promises'
});
